import * as React from 'react';
import 'react-tippy/dist/tippy.css';
import FormFields from '../../../types/FormFields';
import './InputField.css';
export interface InputFieldProps extends FormFields {
    /**
     * type of the input field component ex: email,phone,text
     */
    type?: string;
    /**
     * Callback for OnChange
     */
    onChange?: any;
    /**
     * Name property for Formik
     */
    name?: any;
    /**
     * Value
     */
    value?: any;
    /**
     * Place holder for the field
     */
    placeholder?: string;
    /**
     * Tooltip direction: top | left | right | bottom
     */
    tooltipDirection?: string;
    /**
     * Min value for numbers
     */
    min?: number;
    /**
     * Max value for number
     */
    max: number;
}
interface InputFieldMethods {
    onChange(e: any): any;
    onKeyPress(e: any): any;
    onFocus(): any;
    onBlur(): any;
}
declare class InputField extends React.Component<InputFieldProps & any, any> implements InputFieldMethods {
    constructor(props: InputFieldProps & any);
    /**
     * Update the states with new props only if newprops is changed
     * @param nextProps newly updated props
     */
    componentWillReceiveProps(nextProps: InputFieldProps): void;
    /**
     * Handle onchange of input text
     * @param e Event param
     */
    onChange: (e: any) => void;
    /**
     * On focus set showTooltip if errorbox is true
     * @param e Event param
     */
    onFocus: () => any;
    /**
     * On Focus out, hide showErrorBox
     */
    onBlur: () => any;
    /**
     * Allow keys of only specific characters
     */
    onKeyPress: (e: any) => any;
    render(): JSX.Element;
}
export default InputField;
